pub struct CircuitEvalMap<F: Field>(pub(crate) HashMap<CircuitLocation, MultilinearExtension<F>>);Expand description
A HashMap that records during circuit compilation where nodes live in the circuit and what data they yield.
Tuple Fields
0: HashMap<CircuitLocation, MultilinearExtension<F>>Implementations
Sourceimpl<F: Field> CircuitEvalMap<F>
impl<F: Field> CircuitEvalMap<F>
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new circuit map, which maps circuit location to the data stored at that location.removing
Sourcepub fn get_data_from_circuit_mle(
&self,
circuit_mle: &MleDescription<F>,
) -> Result<&MultilinearExtension<F>>
pub fn get_data_from_circuit_mle( &self, circuit_mle: &MleDescription<F>, ) -> Result<&MultilinearExtension<F>>
Using the circuit location, which is a layer_id and prefix_bits tuple, get the data that exists here.
Sourcepub fn add_node(
&mut self,
circuit_location: CircuitLocation,
value: MultilinearExtension<F>,
)
pub fn add_node( &mut self, circuit_location: CircuitLocation, value: MultilinearExtension<F>, )
Adds a new node to the CircuitMap
Sourcepub fn convert_to_layer_map(self) -> LayerMap<F>
pub fn convert_to_layer_map(self) -> LayerMap<F>
Destructively convert this into a map that maps LayerId to the MultilinearExtensions that generate claims on this area. This is to aid in claim aggregation, so we know the parts of the layerwise bookkeeping table in order to aggregate claims on this layer.