pub type LayerMap<F> = HashMap<LayerId, Vec<DenseMle<F>>>;Expand description
A map that maps layer ID to all the MLEs that are output from that layer. Together these MLEs are combined along with the information from their prefix bits to form the layerwise bookkeeping table.
Aliased Type
pub struct LayerMap<F> { /* private fields */ }